==> hibernate-search-mapper-pojo-base-6.1.3.Final-sources.jar: org/hibernate/search/mapper/pojo/extractor/impl/BoundContainerExtractorPath.java <==
/*
 * Hibernate Search, full-text search for your domain model
 *
 * License: GNU Lesser General Public License (LGPL), version 2.1 or later
 * See the lgpl.txt file in the root directory or <http://www.gnu.org/licenses/lgpl-2.1.html>.
 */
package org.hibernate.search.mapper.pojo.extractor.impl;

import org.hibernate.search.mapper.pojo.extractor.mapping.programmatic.ContainerExtractorPath;
import org.hibernate.search.mapper.pojo.model.spi.PojoGenericTypeModel;

/**
 * A {@link ContainerExtractorPath} bound to a given source type.
 * <p>
 * Instances are returned by the {@code bind}/{@code tryBind} methods of {@link ContainerExtractorBinder}.
 * <p>
 * The {@link #getExtractorPath() extractor path} is guaranteed to be explicit
 * ({@link ContainerExtractorPath#isDefault()} returns {@code false}),
 * and to be valid when applied to the source type.
 * <p>
 * The extractor path may be empty, in which case the source type is equal to the extracted type.
 *
 * @param <C> The container type
 * @param <V> The extracted value type
 */
public class BoundContainerExtractorPath<C, V> {
	public static <V> BoundContainerExtractorPath<V, V> noExtractors(PojoGenericTypeModel<V> sourceType) {
		return new BoundContainerExtractorPath<>(
				ContainerExtractorPath.noExtractors(), sourceType
		);
	}

	private final ContainerExtractorPath extractorPath;
	private final PojoGenericTypeModel<V> extractedType;

	BoundContainerExtractorPath(ContainerExtractorPath extractorPath, PojoGenericTypeModel<V> extractedType) {
		this.extractorPath = extractorPath;
		this.extractedType = extractedType;
	}

	public ContainerExtractorPath getExtractorPath() {
		return extractorPath;
	}

	public PojoGenericTypeModel<V> getExtractedType() {
		return extractedType;
	}
}

==> hibernate-search-mapper-pojo-base-7.2.2.Final-sources.jar: org/hibernate/search/mapper/pojo/extractor/impl/BoundContainerExtractorPath.java <==
/*
 * SPDX-License-Identifier: Apache-2.0
 * Copyright Red Hat Inc. and Hibernate Authors
 */
package org.hibernate.search.mapper.pojo.extractor.impl;

import org.hibernate.search.mapper.pojo.extractor.mapping.programmatic.ContainerExtractorPath;
import org.hibernate.search.mapper.pojo.model.spi.PojoTypeModel;

/**
 * A {@link ContainerExtractorPath} bound to a given source type.
 * <p>
 * Instances are returned by the {@code bind}/{@code tryBind} methods of {@link ContainerExtractorBinder}.
 * <p>
 * The {@link #getExtractorPath() extractor path} is guaranteed to be explicit
 * ({@link ContainerExtractorPath#isDefault()} returns {@code false}),
 * and to be valid when applied to the source type.
 * <p>
 * The extractor path may be empty, in which case the source type is equal to the extracted type.
 *
 * @param <C> The container type
 * @param <V> The extracted value type
 */
public class BoundContainerExtractorPath<C, V> {
	public static <V> BoundContainerExtractorPath<V, V> noExtractors(PojoTypeModel<V> sourceType) {
		return new BoundContainerExtractorPath<>(
				ContainerExtractorPath.noExtractors(), sourceType
		);
	}

	private final ContainerExtractorPath extractorPath;
	private final PojoTypeModel<V> extractedType;

	BoundContainerExtractorPath(ContainerExtractorPath extractorPath, PojoTypeModel<V> extractedType) {
		this.extractorPath = extractorPath;
		this.extractedType = extractedType;
	}

	public ContainerExtractorPath getExtractorPath() {
		return extractorPath;
	}

	public PojoTypeModel<V> getExtractedType() {
		return extractedType;
	}
}
